diff --git a/src/locales/en-US/clusters.ts b/src/locales/en-US/clusters.ts
index d0942e89..ee5dc2aa 100644
--- a/src/locales/en-US/clusters.ts
+++ b/src/locales/en-US/clusters.ts
@@ -45,5 +45,6 @@ export default {
'clusters.create.register.tips':
' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.',
'cluster.create.checkEnv.tips':
- 'Use the following command to check if the environment is ready'
+ 'Use the following command to check if the environment is ready',
+ 'cluster.provider.comingsoon': 'Coming soon'
};
diff --git a/src/locales/ru-RU/clusters.ts b/src/locales/ru-RU/clusters.ts
index 72fabe00..05f94f77 100644
--- a/src/locales/ru-RU/clusters.ts
+++ b/src/locales/ru-RU/clusters.ts
@@ -45,9 +45,11 @@ export default {
'cluster.create.checkEnv.tips':
'Используйте следующую команду для проверки готовности окружения',
'clusters.create.register.tips':
- ' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.'
+ ' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.',
+ 'cluster.provider.comingsoon': 'Coming soon'
};
// ========== To-Do: Translate Keys (Remove After Translation) ==========
// 1. 'clusters.create.register.tips': ' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.',
+// 2. 'cluster.provider.comingsoon': 'Coming soon'
// ========== End of To-Do List ==========
diff --git a/src/locales/zh-CN/clusters.ts b/src/locales/zh-CN/clusters.ts
index 42b94077..899c0d6e 100644
--- a/src/locales/zh-CN/clusters.ts
+++ b/src/locales/zh-CN/clusters.ts
@@ -43,5 +43,6 @@ export default {
' 在需要添加的 Worker 上运行以下命令,将其加入到集群中',
'clusters.create.register.tips':
' 在需要添加的 Kubernetes 集群上运行以下命令,将其中的节点加入到集群中',
- 'cluster.create.checkEnv.tips': '使用以下命令检查环境是否准备妥当'
+ 'cluster.create.checkEnv.tips': '使用以下命令检查环境是否准备妥当',
+ 'cluster.provider.comingsoon': '即将推出'
};
diff --git a/src/pages/cluster-management/components/provider-catalog.tsx b/src/pages/cluster-management/components/provider-catalog.tsx
index ffae42db..1682d041 100644
--- a/src/pages/cluster-management/components/provider-catalog.tsx
+++ b/src/pages/cluster-management/components/provider-catalog.tsx
@@ -95,7 +95,8 @@ const ProviderCatalog: React.FC = ({
}
icon={action.icon}
>
- {action.description}
+ {action.description &&
+ intl.formatMessage({ id: action.description })}
))}
diff --git a/src/pages/cluster-management/config/providers.ts b/src/pages/cluster-management/config/providers.ts
index 9f5994fd..18a0e414 100644
--- a/src/pages/cluster-management/config/providers.ts
+++ b/src/pages/cluster-management/config/providers.ts
@@ -42,7 +42,7 @@ export default [
value: ProviderValueMap.AliCloud,
key: ProviderValueMap.AliCloud,
icon: icons.AliCloud,
- description: 'Coming soon',
+ description: 'cluster.provider.comingsoon',
group: 'clusters.create.provider.cloud'
},
{
@@ -52,7 +52,7 @@ export default [
value: ProviderValueMap.TencentCloud,
key: ProviderValueMap.TencentCloud,
icon: icons.TencentCloud,
- description: 'Coming soon',
+ description: 'cluster.provider.comingsoon',
group: 'clusters.create.provider.cloud'
},
{
@@ -62,7 +62,7 @@ export default [
value: ProviderValueMap.AWS,
key: ProviderValueMap.AWS,
icon: icons.AWS,
- description: 'Comming soon',
+ description: 'cluster.provider.comingsoon',
group: 'clusters.create.provider.cloud'
}
];
diff --git a/src/locales/ja-JP/clusters.ts b/src/locales/ja-JP/clusters.ts
index ae86c818..ee0c0684 100644
--- a/src/locales/ja-JP/clusters.ts
+++ b/src/locales/ja-JP/clusters.ts
@@ -45,7 +45,8 @@ export default {
'cluster.create.checkEnv.tips':
'Use the following command to check if the environment is ready',
'clusters.create.register.tips':
- ' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.'
+ ' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.',
+ 'cluster.provider.comingsoon': 'Coming soon'
};
// ========== To-Do: Translate Keys (Remove After Translation) ==========
@@ -90,6 +91,7 @@ export default {
// 39. 'clusters.create.addworker.tips': ' Please make sure the prerequisites for {label} are met before executing the following command.',
// 40. 'clusters.create.addCommand.tips': ' On the Worker that needs to be added, run the following command to join it to the cluster.',
// 41. 'cluster.create.checkEnv.tips': 'Use the following command to check if the environment is ready',
// 42. 'clusters.create.register.tips': ' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.'
// ========== End of To-Do List ==========
@@ -90,6 +91,7 @@ export default {
// 40. 'clusters.create.addCommand.tips': ' On the Worker that needs to be added, run the following command to join it to the cluster.',
// 41. 'cluster.create.checkEnv.tips': 'Use the following command to check if the environment is ready',
-// 42. 'clusters.create.register.tips': ' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.'
+// 42. 'clusters.create.register.tips': ' On the Kubernetes cluster that needs to be added, run the following command to join its nodes to the cluster.',
+// 43. 'cluster.provider.comingsoon': 'Coming soon'
// ========== End of To-Do List ==========